# 1 install

工具包已经提交到pypi: https://pypi.org/project/pyxllib/
可以直接安装：

```
pip install pyxllib
```

更详细的安装问题见：https://www.yuque.com/xlpr/pyxllib/install

# 2 document

使用文档: https://www.yuque.com/xlpr/pyxllib ，
正在努力完善中，欢迎更多小伙伴一起助力
